/**
 * @preserve
 * Copyright (c) 2015, Igor Bezkrovny
 * All rights reserved. (MIT Licensed)
 *
 * iq.ts - Image Quantization Library
 */
/// <reference path='iq.ts' />

declare var module : any;
module.exports = IQ;

