/**
 * @preserve
 * Copyright (c) 2015, Igor Bezkrovny
 * All rights reserved. (MIT Licensed)
 *
 * iq.ts - Image Quantization Library
 */

/// <reference path='distance/common.ts' />
/// <reference path='color/constants.ts' />
/// <reference path='color/conversion.ts' />

///<reference path="utils/arithmetic.ts"/>
/// <reference path='distance/common.ts' />
/// <reference path='distance/euclidean.ts' />
/// <reference path='distance/euclideanRgbQuant_.ts' />
/// <reference path='distance/euclideanWuQuant.ts' />
/// <reference path='distance/manhattan.ts' />
/// <reference path='distance/manhattanNeuQuant_.ts' />
/// <reference path='distance/cie94.ts' />
/// <reference path='distance/ciede2000.ts' />
/// <reference path='distance/ciede2000_original.ts' />
/// <reference path='distance/cmetric.ts' />
/// <reference path='distance/pngQuant.ts' />

/// <reference path='utils/point.ts' />
/// <reference path='utils/palette.ts' />
/// <reference path='utils/pointContainer.ts' />
/// <reference path='utils/hueStatistics.ts' />

/// <reference path='image/common.ts' />
/// <reference path='image/ditherErrorDiffusion.ts' />
/// <reference path='image/nearestColor.ts' />

/// <reference path="palette/common.ts"/>
/// <reference path="palette/neuquant/neuquant.ts"/>
/// <reference path="palette/rgbquant/rgbquant.ts"/>
/// <reference path="palette/wu/wuQuant.ts"/>

/// <reference path="quality/ssim.ts"/>

/// <reference path='utils/utils.ts' />
